### AUTOUPDATE-OFF: 4
%define        majversion  %(echo %version | cut -d. -f 1)
Name:          R
Version:       4.5.0
Release:       1mamba
Summary:       R is a free software environment for statistical computing and graphics
Group:         Applications/Mathematics
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.r-project.org/
Source:        http://cran.r-project.org/src/base/R-%{majversion}/R-%{version}.tar.gz
Source1:       %{name}.png
Patch0:        R-2.15.2-texinfo-5.0.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: gcc-fortran
BuildRequires: glibc-devel
BuildRequires: libICE-devel
BuildRequires: libSM-devel
BuildRequires: libX11-devel
BuildRequires: libXext-devel
BuildRequires: libXmu-devel
BuildRequires: libXt-devel
BuildRequires: libbzip2-devel
BuildRequires: libcairo-devel
BuildRequires: libcurl-devel
BuildRequires: libglib-devel
BuildRequires: libgomp-devel
BuildRequires: libharfbuzz-devel
BuildRequires: libicu-devel
BuildRequires: libjpeg-devel
BuildRequires: liblzma-devel
BuildRequires: libncurses-devel
BuildRequires: libpango-devel
BuildRequires: libpcre2-devel
BuildRequires: libpng-devel
%ifnarch arm aarch64
BuildRequires: libquadmath-devel
%endif
BuildRequires: libreadline-devel
BuildRequires: libtiff-devel
BuildRequires: libtirpc-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
BuildRequires: tetex-latex
BuildRequires: libtk
BuildRequires: paper-utils
BuildRequires: liblapack-devel
BuildRequires: libX11-devel >= 1.1.1
BuildRequires: libpcre-devel
BuildRequires: latex-font-inconsolata
%ifnarch arm aarch64
BuildRequires: libquadmath-devel
%endif
Requires:      latex-font-inconsolata
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires(post):%{__install_info}

%description
R is a language and environment for statistical computing and graphics.
It is a GNU project which is similar to the S language and environment which was developed at Bell Laboratories (formerly AT&T, now Lucent Technologies) by John Chambers and colleagues.
R can be considered as a different implementation of S.
There are some important differences, but much code written for S runs unaltered under R.

R provides a wide variety of statistical (linear and nonlinear modelling, 
classical statistical tests, time-series analysis, classification, clustering, ...) and graphical techniques, and is highly extensible.
The S language is often the vehicle of choice for research in statistical methodology, and R provides an Open Source route to participation in that activity.

One of R's strengths is the ease with which well-designed publication-quality plots can be produced, including mathematical symbols and formulae where needed. Great care has been taken over the defaults for the minor design choices in graphics, but the user retains full control. 

%package -n lib%{name}
Group:         System/Libraries
Summary:       Shared libraries for %{name}

%description -n lib%{name}
This package contains shared libraries for %{name}.

%package -n lib%{name}-devel
Group:         Development/Libraries
Summary:       Development files for %{name}
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      pkg-config

%description -n lib%{name}-devel
This package contains libraries and header files for developing applications that use %{name}.


%prep
%setup -q

%build
echo 'R_LIBS_SITE=${R_LIBS_SITE-'"'/usr/local/lib/R/site-library:/usr/local/lib/R/library:%{_libdir}/R/library:%{_datadir}/R/library'"'}' >> etc/Renviron.in
export R_PDFVIEWER="%{_bindir}/xdg-open"
export R_PRINTCMD="lpr"
export R_BROWSER="%{_bindir}/xdg-open"

%configure \
   --enable-R-shlib \
   LIBS="-lncurses" \
   ac_cv_path_INSTALL_INFO=/sbin/install-info


%make R_LIBS_USER=`pwd`/library
%make pdf info

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall install-info
rm -f %{buildroot}%{_infodir}/dir
rm -f %{buildroot}%{_infodir}/dir.old

# Fix location of R_HOME_DIR in shell wrapper
sed -e "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/%{name}@" < bin/%{name} \
   > %{buildroot}%{_libdir}/R/bin/%{name}
sed -e "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/%{name}@" < bin/%{name} \
   > %{buildroot}%{_bindir}/%{name}
chmod 755 %{buildroot}%{_libdir}/%{name}/bin/%{name}
chmod 755 %{buildroot}%{_bindir}/%{name}

# Remove package indices. They are rebuilt by the %post script
rm -f %{buildroot}%{_libdir}/%{name}/doc/html/function.html
rm -f %{buildroot}%{_libdir}/%{name}/doc/html/packages.html
rm -f %{buildroot}%{_libdir}/%{name}/doc/html/search/index.txt

# Remove duplicated documentation files
(cd %{buildroot}%{_libdir}/R; \
   rm -f COPYING NEWS doc/AUTHORS doc/COPYING doc/COPYING.LIB \
      doc/COPYRIGHTS doc/NEWS doc/THANKS
)

# Create the system menu entry
install -D -m 644 %{S:1} \
   %{buildroot}%{_datadir}/icons/crystalsvg/16x16/apps/%{name}.png
install -d %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=%{name}
GenericName=Development environment for statistical computing
GenericName[it]=Ambiente di sviluppo per l'analisi statistica
Exec=%{name}
Icon=%{name}
Terminal=1
Type=Application
X-KDE-StartupNotify=true
Categories=Application;Development;
EOF

install -d -m0755 %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/R.conf << _EOF
%{_libdir}/%{name}/lib
_EOF

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%define info_files %{name}-admin %{name}-data %{name}-exts %{name}-FAQ %{name}-intro %{name}-ints %{name}-lang

%post
#%ifnarch x86_64
for info_file in %info_files
   do %install_info $info_file.info
done
#%endif

## Update package indices
#%{_bindir}/%{name} CMD perl %{_libdir}/%{name}/share/perl/build-help.pl \
#   --htmllists &>/dev/null
#cat %{_libdir}/%{name}/library/*/CONTENTS \
#   > %{_libdir}/%{name}/doc/html/search/index.txt 2>/dev/null
:

%preun
#%ifnarch x86_64
for info_file in %info_files
   do %uninstall_info $info_file.info
done
#%endif
:


%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_bindir}/Rscript
%{_datadir}/icons/crystalsvg/16x16/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/*
%{_infodir}/R-*.info*.gz
%doc COPYING

%files -n lib%{name}
%defattr(-,root,root)
%{_sysconfdir}/ld.so.conf.d/R.conf
%dir %{_libdir}/R
%{_libdir}/R/SVN-REVISION
%dir %{_libdir}/R/bin
%{_libdir}/R/bin/*
%dir %{_libdir}/R/etc
%{_libdir}/R/etc/*
%dir %{_libdir}/R/lib
%{_libdir}/R/lib/*.so
%dir %{_libdir}/R/modules
%{_libdir}/R/modules/*.so
%dir %{_libdir}/R/library
%{_libdir}/R/library/*
%dir %{_libdir}/R/share
%{_libdir}/R/share/*

%files -n lib%{name}-devel
%defattr(-,root,root)
%dir %{_libdir}/R/include
%{_libdir}/R/include/*
%dir %{_libdir}/R/doc
%{_libdir}/R/doc/*
%{_libdir}/pkgconfig/libR.pc
%doc doc/manual/R-admin.pdf
%doc doc/manual/R-FAQ.pdf
%doc doc/manual/R-lang.pdf
%doc doc/manual/R-data.pdf
%doc doc/manual/R-intro.pdf

%changelog
* Sat Apr 12 2025 Automatic Build System <autodist@openmamba.org> 4.5.0-1mamba
- automatic version update by autodist

* Fri Feb 28 2025 Automatic Build System <autodist@openmamba.org> 4.4.3-1mamba
- automatic version update by autodist

* Sat Nov 02 2024 Automatic Build System <autodist@openmamba.org> 4.4.2-1mamba
- automatic version update by autodist

* Fri Jun 14 2024 Automatic Build System <autodist@openmamba.org> 4.4.1-1mamba
- automatic version update by autodist

* Wed Apr 24 2024 Automatic Build System <autodist@openmamba.org> 4.4.0-1mamba
- automatic version update by autodist

* Thu Feb 29 2024 Automatic Build System <autodist@openmamba.org> 4.3.3-1mamba
- automatic version update by autodist

* Tue Oct 31 2023 Automatic Build System <autodist@mambasoft.it> 4.3.2-1mamba
- automatic version update by autodist

* Fri Jun 30 2023 Automatic Build System <autodist@mambasoft.it> 4.3.1-1mamba
- automatic version update by autodist

* Sun Apr 23 2023 Automatic Build System <autodist@mambasoft.it> 4.3.0-1mamba
- automatic version update by autodist

* Thu Mar 16 2023 Automatic Build System <autodist@mambasoft.it> 4.2.3-1mamba
- automatic version update by autodist

* Mon Oct 31 2022 Automatic Build System <autodist@mambasoft.it> 4.2.2-1mamba
- automatic version update by autodist

* Thu Jun 23 2022 Automatic Build System <autodist@mambasoft.it> 4.2.1-1mamba
- automatic version update by autodist

* Sat Apr 23 2022 Automatic Build System <autodist@mambasoft.it> 4.2.0-1mamba
- automatic version update by autodist

* Fri Mar 11 2022 Automatic Build System <autodist@mambasoft.it> 4.1.3-1mamba
- automatic version update by autodist

* Tue Nov 02 2021 Automatic Build System <autodist@mambasoft.it> 4.1.2-1mamba
- automatic version update by autodist

* Tue Aug 10 2021 Automatic Build System <autodist@mambasoft.it> 4.1.1-1mamba
- automatic version update by autodist

* Tue May 18 2021 Automatic Build System <autodist@mambasoft.it> 4.1.0-1mamba
- automatic version update by autodist

* Wed Mar 31 2021 Automatic Build System <autodist@mambasoft.it> 4.0.5-1mamba
- automatic version update by autodist

* Mon Feb 22 2021 Automatic Build System <autodist@mambasoft.it> 4.0.4-1mamba
- automatic version update by autodist

* Thu Jun 18 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.3-3mamba
- add libR and libR-devel packages

* Thu Jun 18 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 3.6.3-2mamba
- fix paths in pkgconfig file

* Mon May 04 2020 Automatic Build System <autodist@mambasoft.it> 3.6.3-1mamba
- automatic update by autodist

* Thu Dec 07 2017 Automatic Build System <autodist@mambasoft.it> 3.4.3-1mamba
- automatic update by autodist

* Mon Mar 16 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1.3-1mamba
- update to 3.1.3

* Fri Nov 21 2014 Automatic Build System <autodist@mambasoft.it> 3.1.2-1mamba
- automatic update by autodist

* Sun Jul 13 2014 Automatic Build System <autodist@mambasoft.it> 3.1.1-1mamba
- automatic update by autodist

* Wed May 28 2014 Automatic Build System <autodist@mambasoft.it> 3.1.0-1mamba
- automatic update by autodist

* Mon Sep 30 2013 Automatic Build System <autodist@mambasoft.it> 3.0.2-1mamba
- automatic update by autodist

* Thu Jun 13 2013 Automatic Build System <autodist@mambasoft.it> 3.0.1-1mamba
- automatic version update by autodist

* Tue May 07 2013 Automatic Build System <autodist@mambasoft.it> 3.0.0-1mamba
- automatic version update by autodist

* Thu Mar 07 2013 Automatic Build System <autodist@mambasoft.it> 2.15.3-1mamba
- automatic version update by autodist

* Sat Oct 27 2012 Automatic Build System <autodist@mambasoft.it> 2.15.2-1mamba
- automatic version update by autodist

* Wed Aug 15 2012 Automatic Build System <autodist@mambasoft.it> 2.15.1-1mamba
- automatic version update by autodist

* Mon Jun 11 2012 Stefano Cotta Ramusino <stefano.cotta@openmamba.org> 2.15.0-2mamba
- Add R library path to configuration file for R packages

* Sat Jun 09 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 2.15.0-1mamba
- update to 2.15.0

* Fri Mar 04 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.12.2-1mamba
- update to 2.12.2
- rebuilt with --enable-R-shlib

* Tue Feb 22 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.11.1-4mamba
- use /etc/ld.conf.d pluggable directory to set library directory
- remove index creation in post scripts

* Wed Jan 12 2011 Automatic Build System <autodist@mambasoft.it> 2.11.1-3mamba
- automatic update by autodist

* Tue Jun 29 2010 Automatic Build System <autodist@mambasoft.it> 2.11.1-2mamba
- automatic rebuild by autodist

* Sat Jun 26 2010 Automatic Build System <autodist@mambasoft.it> 2.11.1-1mamba
- automatic update by autodist

* Tue Apr 27 2010 Automatic Build System <autodist@mambasoft.it> 2.11.0-1mamba
- automatic update by autodist

* Tue Jan 26 2010 Automatic Build System <autodist@mambasoft.it> 2.10.1-1mamba
- automatic update by autodist

* Wed Oct 28 2009 Automatic Build System <autodist@mambasoft.it> 2.10.0-1mamba
- automatic update by autodist

* Fri Aug 28 2009 Automatic Build System <autodist@mambasoft.it> 2.9.2-1mamba
- automatic update by autodist

* Sat Jul 04 2009 Automatic Build System <autodist@mambasoft.it> 2.9.1-1mamba
- automatic update by autodist

* Thu Jun 25 2009 Automatic Build System <autodist@mambasoft.it> 2.9.0-1mamba
- automatic update by autodist

* Wed Jan 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 2.8.1-1mamba
- automatic update by autodist

* Fri Sep 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 2.7.2-1mamba
- update to 2.7.2

* Sat May 19 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.5.0-1mamba
- update to 2.5.0

* Sun Feb 18 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.1-2qilnx
- rebuilt

* Tue Feb 06 2007 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.4.1-1qilnx
- update to version 2.4.1 by autospec

* Sat Nov 18 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 2.4.0-1qilnx
- package created by autospec
